@@ -17,7 +17,7 @@
    Boston, MA 02110-1301, USA.
 */
 #include "sieveeditortabwidget.h"
-#include "ksieveui/editor/sieveeditorhelphtmlwidget.h"
+#include "webengine/sieveeditorhelphtmlwidget.h"
 
 #include <KLocalizedString>
 #include <KStringHandler>
@@ -115,6 +115,12 @@ void SieveEditorTabWidget::slotTabCloseRequested(int index)
     }
 }
 
+bool SieveEditorTabWidget::currentPageIsHtmlPage() const
+{
+    SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
+    return page ? true : false;
+}
+
 QUrl SieveEditorTabWidget::currentHelpUrl() const
 {
     SieveEditorHelpHtmlWidget *page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
