@@ -22,18 +22,32 @@
 #include <QFileDialog>
 #include <QWebEngineDownloadItem>
 #include <QWebEngineProfile>
+#include <QWebEngineSettings>
 
 using namespace KSieveUi;
 
 SieveEditorWebEngineView::SieveEditorWebEngineView(QWidget *parent)
     : QWebEngineView(parent)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
     QWebEngineProfile *profile = new QWebEngineProfile(this);
     QWebEnginePage *page = new QWebEnginePage(profile, this);
-    setPage(page);
+    page->settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, false);
+    page->settings()->setAttribute(QWebEngineSettings::PluginsEnabled, false);
+    page->settings()->setAttribute(QWebEngineSettings::AutoLoadImages, false);
+    page->settings()->setAttribute(QWebEngineSettings::JavascriptCanOpenWindows, false);
+    page->settings()->setAttribute(QWebEngineSettings::JavascriptCanAccessClipboard, false);
+    page->settings()->setAttribute(QWebEngineSettings::LocalStorageEnabled, false);
+    page->settings()->setAttribute(QWebEngineSettings::XSSAuditingEnabled, false);
+    page->settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, false);
+    page->settings()->setAttribute(QWebEngineSettings::ErrorPageEnabled, false);
+    page->settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessFileUrls, false);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
+    page->settings()->setAttribute(QWebEngineSettings::ScreenCaptureEnabled, false);
+    page->settings()->setAttribute(QWebEngineSettings::FullScreenSupportEnabled, false);
+    page->settings()->setAttribute(QWebEngineSettings::WebGLEnabled, false);
     connect(profile, &QWebEngineProfile::downloadRequested, this, &SieveEditorWebEngineView::downloadRequested);
 #endif
+    setPage(page);
 }
 
 SieveEditorWebEngineView::~SieveEditorWebEngineView()
@@ -110,3 +124,12 @@ void SieveEditorWebEngineView::contextMenuEvent(QContextMenuEvent *ev)
     menu.exec(ev->globalPos());
 }
 
+QWebEngineView *SieveEditorWebEngineView::createWindow(QWebEnginePage::WebWindowType type)
+{
+    Q_UNUSED(type);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
+    return this;
+#else
+    return Q_NULLPTR;
+#endif
+}
