@@ -23,6 +23,7 @@
 #include <QDialog>
 #include "ksieveui_export.h"
 
+class QPushButton;
 namespace KSieveUi
 {
 class SieveScriptDebuggerWidget;
@@ -36,13 +37,14 @@ public:
     void setScript(const QString &script);
     QString script() const;
 
-private Q_SLOTS:
-    void slotAccepted();
-
 private:
+    void slotScriptTextChanged();
+    void slotAccepted();
     void writeConfig();
     void readConfig();
+    QString mOriginScript;
     SieveScriptDebuggerWidget *mSieveScriptDebuggerWidget;
+    QPushButton *mOkButton;
 };
 }
 
